"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.environment.clusters_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _InformerAction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _InformerActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_InformerAction.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ADD: _InformerAction.ValueType  # 0
    UPDATE: _InformerAction.ValueType  # 1
    DELETE: _InformerAction.ValueType  # 2

class InformerAction(_InformerAction, metaclass=_InformerActionEnumTypeWrapper): ...

ADD: InformerAction.ValueType  # 0
UPDATE: InformerAction.ValueType  # 1
DELETE: InformerAction.ValueType  # 2
global___InformerAction = InformerAction

class HeartbeatReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """TODO(naphat) there needs to be some auth/id for agent"""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___HeartbeatReq = HeartbeatReq

class HeartbeatResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___HeartbeatResp = HeartbeatResp

class RecordNewUnknownPushReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_CHANNEL_ID_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    release_channel_id: builtins.str
    service_id: builtins.str
    cluster_id: builtins.str
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        release_channel_id: builtins.str = ...,
        service_id: builtins.str = ...,
        cluster_id: builtins.str = ...,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "creation_timestamp", b"creation_timestamp", "release_channel_id", b"release_channel_id", "service_id", b"service_id"]) -> None: ...

global___RecordNewUnknownPushReq = RecordNewUnknownPushReq

class RecordNewUnknownPushResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RecordNewUnknownPushResp = RecordNewUnknownPushResp

class RecordPushStartReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_CHANNEL_ID_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    START_TIMESTAMP_FIELD_NUMBER: builtins.int
    release_channel_id: builtins.str
    service_id: builtins.str
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    cluster_id: builtins.str
    @property
    def start_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        release_channel_id: builtins.str = ...,
        service_id: builtins.str = ...,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        cluster_id: builtins.str = ...,
        start_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "start_timestamp", b"start_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "creation_timestamp", b"creation_timestamp", "release_channel_id", b"release_channel_id", "service_id", b"service_id", "start_timestamp", b"start_timestamp"]) -> None: ...

global___RecordPushStartReq = RecordPushStartReq

class RecordPushStartResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RecordPushStartResp = RecordPushStartResp

class RecordPushOngoingReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_CHANNEL_ID_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    release_channel_id: builtins.str
    service_id: builtins.str
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    cluster_id: builtins.str
    def __init__(
        self,
        *,
        release_channel_id: builtins.str = ...,
        service_id: builtins.str = ...,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "creation_timestamp", b"creation_timestamp", "release_channel_id", b"release_channel_id", "service_id", b"service_id"]) -> None: ...

global___RecordPushOngoingReq = RecordPushOngoingReq

class RecordPushOngoingResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RecordPushOngoingResp = RecordPushOngoingResp

class RecordPushCompleteReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RecordPushCompleteReq._Type.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: RecordPushCompleteReq._Type.ValueType  # 0
        SUCCEEDED: RecordPushCompleteReq._Type.ValueType  # 1
        ROLLED_BACK: RecordPushCompleteReq._Type.ValueType  # 2

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    UNKNOWN: RecordPushCompleteReq.Type.ValueType  # 0
    SUCCEEDED: RecordPushCompleteReq.Type.ValueType  # 1
    ROLLED_BACK: RecordPushCompleteReq.Type.ValueType  # 2

    RELEASE_CHANNEL_ID_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    release_channel_id: builtins.str
    service_id: builtins.str
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    cluster_id: builtins.str
    type: global___RecordPushCompleteReq.Type.ValueType
    def __init__(
        self,
        *,
        release_channel_id: builtins.str = ...,
        service_id: builtins.str = ...,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        cluster_id: builtins.str = ...,
        type: global___RecordPushCompleteReq.Type.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "creation_timestamp", b"creation_timestamp", "release_channel_id", b"release_channel_id", "service_id", b"service_id", "type", b"type"]) -> None: ...

global___RecordPushCompleteReq = RecordPushCompleteReq

class RecordPushCompleteResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RecordPushCompleteResp = RecordPushCompleteResp

class ConfirmPushApprovalReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_CHANNEL_ID_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    release_channel_id: builtins.str
    service_id: builtins.str
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    cluster_id: builtins.str
    def __init__(
        self,
        *,
        release_channel_id: builtins.str = ...,
        service_id: builtins.str = ...,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "creation_timestamp", b"creation_timestamp", "release_channel_id", b"release_channel_id", "service_id", b"service_id"]) -> None: ...

global___ConfirmPushApprovalReq = ConfirmPushApprovalReq

class ConfirmPushApprovalResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPROVED_FIELD_NUMBER: builtins.int
    approved: builtins.bool
    def __init__(
        self,
        *,
        approved: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["approved", b"approved"]) -> None: ...

global___ConfirmPushApprovalResp = ConfirmPushApprovalResp

class RecordPodReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POD_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    RUNTIME_ID_FIELD_NUMBER: builtins.int
    pod: builtins.bytes
    action: global___InformerAction.ValueType
    runtime_id: builtins.str
    def __init__(
        self,
        *,
        pod: builtins.bytes = ...,
        action: global___InformerAction.ValueType = ...,
        runtime_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "pod", b"pod", "runtime_id", b"runtime_id"]) -> None: ...

global___RecordPodReq = RecordPodReq

class RecordPodResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RecordPodResp = RecordPodResp

class RecordPodsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PODS_FIELD_NUMBER: builtins.int
    RUNTIME_ID_FIELD_NUMBER: builtins.int
    @property
    def pods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...
    runtime_id: builtins.str
    """If we're running into perf/size limits with number of pods in a service, add "shard"/"count" fields
    to overwrite a determinstic slice of pods.
    """
    def __init__(
        self,
        *,
        pods: collections.abc.Iterable[builtins.bytes] | None = ...,
        runtime_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pods", b"pods", "runtime_id", b"runtime_id"]) -> None: ...

global___RecordPodsReq = RecordPodsReq

class RecordPodsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RecordPodsResp = RecordPodsResp

class RecordDeploymentReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    deployment: builtins.bytes
    action: global___InformerAction.ValueType
    def __init__(
        self,
        *,
        deployment: builtins.bytes = ...,
        action: global___InformerAction.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "deployment", b"deployment"]) -> None: ...

global___RecordDeploymentReq = RecordDeploymentReq

class RecordDeploymentResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUSH_TIMESTAMP_FIELD_NUMBER: builtins.int
    @property
    def push_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        push_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["push_timestamp", b"push_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["push_timestamp", b"push_timestamp"]) -> None: ...

global___RecordDeploymentResp = RecordDeploymentResp

class RecordRolloutReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLLOUT_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    rollout: builtins.bytes
    action: global___InformerAction.ValueType
    def __init__(
        self,
        *,
        rollout: builtins.bytes = ...,
        action: global___InformerAction.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "rollout", b"rollout"]) -> None: ...

global___RecordRolloutReq = RecordRolloutReq

class RecordRolloutResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUSH_TIMESTAMP_FIELD_NUMBER: builtins.int
    @property
    def push_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        push_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["push_timestamp", b"push_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["push_timestamp", b"push_timestamp"]) -> None: ...

global___RecordRolloutResp = RecordRolloutResp

class ProxyAPIServerReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_ID_FIELD_NUMBER: builtins.int
    BLOB_FIELD_NUMBER: builtins.int
    CONN_ID_FIELD_NUMBER: builtins.int
    runtime_id: builtins.str
    """Header"""
    blob: builtins.bytes
    """Everything after header"""
    conn_id: builtins.str
    """Debugging/logging bits"""
    def __init__(
        self,
        *,
        runtime_id: builtins.str = ...,
        blob: builtins.bytes = ...,
        conn_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["blob", b"blob", "msg", b"msg", "runtime_id", b"runtime_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["blob", b"blob", "conn_id", b"conn_id", "msg", b"msg", "runtime_id", b"runtime_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["msg", b"msg"]) -> typing_extensions.Literal["runtime_id", "blob"] | None: ...

global___ProxyAPIServerReq = ProxyAPIServerReq

class ProxyAPIServerResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ProxyAPIServerResp._Type.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: ProxyAPIServerResp._Type.ValueType  # 0
        PROXY_APISERVER: ProxyAPIServerResp._Type.ValueType  # 1
        """More operations like docker registry interactions"""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    UNKNOWN: ProxyAPIServerResp.Type.ValueType  # 0
    PROXY_APISERVER: ProxyAPIServerResp.Type.ValueType  # 1
    """More operations like docker registry interactions"""

    TYPE_FIELD_NUMBER: builtins.int
    BLOB_FIELD_NUMBER: builtins.int
    type: global___ProxyAPIServerResp.Type.ValueType
    """Header"""
    blob: builtins.bytes
    def __init__(
        self,
        *,
        type: global___ProxyAPIServerResp.Type.ValueType = ...,
        blob: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["blob", b"blob", "msg", b"msg", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["blob", b"blob", "msg", b"msg", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["msg", b"msg"]) -> typing_extensions.Literal["type", "blob"] | None: ...

global___ProxyAPIServerResp = ProxyAPIServerResp

class DebugInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_FIELD_NUMBER: builtins.int
    TCPTRACEROUTE_OUT_FIELD_NUMBER: builtins.int
    error: builtins.str
    """set only if there's any error running debug commands"""
    tcptraceroute_out: builtins.str
    def __init__(
        self,
        *,
        error: builtins.str = ...,
        tcptraceroute_out: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error", b"error", "tcptraceroute_out", b"tcptraceroute_out"]) -> None: ...

global___DebugInfo = DebugInfo

class ReportDebugInfoReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_ID_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    runtime_id: builtins.str
    @property
    def info(self) -> global___DebugInfo: ...
    def __init__(
        self,
        *,
        runtime_id: builtins.str = ...,
        info: global___DebugInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["info", b"info", "runtime_id", b"runtime_id"]) -> None: ...

global___ReportDebugInfoReq = ReportDebugInfoReq

class ReportDebugInfoResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReportDebugInfoResp = ReportDebugInfoResp

class ReportClusterMetadataReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_ID_FIELD_NUMBER: builtins.int
    CLUSTER_METADATA_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    runtime_id: builtins.str
    @property
    def cluster_metadata(self) -> prodvana.proto.prodvana.environment.clusters_pb2.ClusterMetadata: ...
    error: builtins.str
    """For debugging"""
    def __init__(
        self,
        *,
        runtime_id: builtins.str = ...,
        cluster_metadata: prodvana.proto.prodvana.environment.clusters_pb2.ClusterMetadata | None = ...,
        error: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_metadata", b"cluster_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_metadata", b"cluster_metadata", "error", b"error", "runtime_id", b"runtime_id"]) -> None: ...

global___ReportClusterMetadataReq = ReportClusterMetadataReq

class ReportClusterMetadataResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ReportClusterMetadataResp = ReportClusterMetadataResp



import os

from prodvana.client import Client
from prodvana.proto.prodvana.desired_state import manager_pb2


def get_desired_state_details(client: Client) -> manager_pb2.DesiredStateSummary:
    desired_state_id = os.getenv("PVN_DESIRED_STATE_ID")
    assert desired_state_id, "PVN_DESIRED_STATE_ID not set"
    summary_resp = client.desired_state_manager.GetDesiredStateConvergenceSummary(
        manager_pb2.GetDesiredStateConvergenceReq(
            desired_state_id=desired_state_id,
        )
    )
    return summary_resp.summary



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vtproto/ext.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11vtproto/ext.proto\x12\x07vtproto\x1a google/protobuf/descriptor.proto:2\n\x07mempool\x12\x1f.google.protobuf.MessageOptions\x18\xe5\xf4\x03 \x01(\x08:;\n\x12unstable_for_equal\x12\x1d.google.protobuf.FieldOptions\x18\xe5\xf4\x03 \x01(\x08\x42I\n\x13\x63om.google.protobufB\x07VTProtoZ)github.com/planetscale/vtprotobuf/vtproto')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vtproto.ext_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(mempool)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(unstable_for_equal)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.google.protobufB\007VTProtoZ)github.com/planetscale/vtprotobuf/vtproto'
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.desired_state.model.desired_state_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class EntityDumpState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class IOState(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LAST_FETCHED_TIMESTAMP_FIELD_NUMBER: builtins.int
        LAST_APPLIED_TIMESTAMP_FIELD_NUMBER: builtins.int
        EXPECTED_NEXT_APPLY_TIMESTAMP_FIELD_NUMBER: builtins.int
        @property
        def last_fetched_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        @property
        def last_applied_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        @property
        def expected_next_apply_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            last_fetched_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            last_applied_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            expected_next_apply_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["expected_next_apply_timestamp", b"expected_next_apply_timestamp", "last_applied_timestamp", b"last_applied_timestamp", "last_fetched_timestamp", b"last_fetched_timestamp"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["expected_next_apply_timestamp", b"expected_next_apply_timestamp", "last_applied_timestamp", b"last_applied_timestamp", "last_fetched_timestamp", b"last_fetched_timestamp"]) -> None: ...

    class ChildState(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        STATUS_FIELD_NUMBER: builtins.int
        @property
        def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
        status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
        def __init__(
            self,
            *,
            id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
            status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["id", b"id"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "status", b"status"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    LAST_MANAGER_UPDATE_TIMESTAMP_FIELD_NUMBER: builtins.int
    ANNOTATIONS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SIMPLE_STATUS_FIELD_NUMBER: builtins.int
    CONTROL_FIELD_NUMBER: builtins.int
    IO_STATE_FIELD_NUMBER: builtins.int
    LOGS_FIELD_NUMBER: builtins.int
    DESIRED_STATE_FIELD_NUMBER: builtins.int
    FETCHED_STATE_FIELD_NUMBER: builtins.int
    TARGET_STATE_FIELD_NUMBER: builtins.int
    CHILD_STATES_FIELD_NUMBER: builtins.int
    ABSENT_FIELD_NUMBER: builtins.int
    DELETED_FIELD_NUMBER: builtins.int
    OBSERVER_FIELD_NUMBER: builtins.int
    STALE_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    @property
    def last_manager_update_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def annotations(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Annotations: ...
    status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
    simple_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SimpleStatus.ValueType
    @property
    def control(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ControlState: ...
    @property
    def io_state(self) -> global___EntityDumpState.IOState: ...
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DebugLog]: ...
    @property
    def desired_state(self) -> google.protobuf.any_pb2.Any: ...
    @property
    def fetched_state(self) -> google.protobuf.any_pb2.Any: ...
    @property
    def target_state(self) -> google.protobuf.any_pb2.Any: ...
    @property
    def child_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EntityDumpState.ChildState]: ...
    absent: builtins.bool
    deleted: builtins.bool
    observer: builtins.bool
    stale: builtins.bool
    def __init__(
        self,
        *,
        id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        last_manager_update_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        annotations: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Annotations | None = ...,
        status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        simple_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SimpleStatus.ValueType = ...,
        control: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ControlState | None = ...,
        io_state: global___EntityDumpState.IOState | None = ...,
        logs: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DebugLog] | None = ...,
        desired_state: google.protobuf.any_pb2.Any | None = ...,
        fetched_state: google.protobuf.any_pb2.Any | None = ...,
        target_state: google.protobuf.any_pb2.Any | None = ...,
        child_states: collections.abc.Iterable[global___EntityDumpState.ChildState] | None = ...,
        absent: builtins.bool = ...,
        deleted: builtins.bool = ...,
        observer: builtins.bool = ...,
        stale: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "control", b"control", "desired_state", b"desired_state", "fetched_state", b"fetched_state", "id", b"id", "io_state", b"io_state", "last_manager_update_timestamp", b"last_manager_update_timestamp", "target_state", b"target_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["absent", b"absent", "annotations", b"annotations", "child_states", b"child_states", "control", b"control", "deleted", b"deleted", "desired_state", b"desired_state", "fetched_state", b"fetched_state", "id", b"id", "io_state", b"io_state", "last_manager_update_timestamp", b"last_manager_update_timestamp", "logs", b"logs", "observer", b"observer", "simple_status", b"simple_status", "stale", b"stale", "status", b"status", "target_state", b"target_state"]) -> None: ...

global___EntityDumpState = EntityDumpState

class DumpState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITIES_FIELD_NUMBER: builtins.int
    @property
    def entities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EntityDumpState]: ...
    def __init__(
        self,
        *,
        entities: collections.abc.Iterable[global___EntityDumpState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entities", b"entities"]) -> None: ...

global___DumpState = DumpState



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/env.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n prodvana/common_config/env.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\"\xbe\x01\n\x08\x45nvValue\x12\x0f\n\x05value\x18\x01 \x01(\tH\x00\x12\x14\n\nraw_secret\x18\x02 \x01(\tH\x00\x12\x30\n\x06secret\x18\x03 \x01(\x0b\x32\x1e.prodvana.common_config.SecretH\x00\x12\x45\n\x11kubernetes_secret\x18\x04 \x01(\x0b\x32(.prodvana.common_config.KubernetesSecretH\x00\x42\x12\n\x0bvalue_oneof\x12\x03\xf8\x42\x01\"\xa3\x01\n\x14SecretReferenceValue\x12\x30\n\x06secret\x18\x01 \x01(\x0b\x32\x1e.prodvana.common_config.SecretH\x00\x12\x45\n\x11kubernetes_secret\x18\x02 \x01(\x0b\x32(.prodvana.common_config.KubernetesSecretH\x00\x42\x12\n\x0bvalue_oneof\x12\x03\xf8\x42\x01\"8\n\x06Secret\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07version\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"F\n\x10KubernetesSecret\x12\x1c\n\x0bsecret_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x14\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.env_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _ENVVALUE.oneofs_by_name['value_oneof']._options = None
  _ENVVALUE.oneofs_by_name['value_oneof']._serialized_options = b'\370B\001'
  _SECRETREFERENCEVALUE.oneofs_by_name['value_oneof']._options = None
  _SECRETREFERENCEVALUE.oneofs_by_name['value_oneof']._serialized_options = b'\370B\001'
  _SECRET.fields_by_name['key']._options = None
  _SECRET.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _SECRET.fields_by_name['version']._options = None
  _SECRET.fields_by_name['version']._serialized_options = b'\372B\004r\002\020\001'
  _KUBERNETESSECRET.fields_by_name['secret_name']._options = None
  _KUBERNETESSECRET.fields_by_name['secret_name']._serialized_options = b'\372B\004r\002\020\001'
  _KUBERNETESSECRET.fields_by_name['key']._options = None
  _KUBERNETESSECRET.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_ENVVALUE']._serialized_start=86
  _globals['_ENVVALUE']._serialized_end=276
  _globals['_SECRETREFERENCEVALUE']._serialized_start=279
  _globals['_SECRETREFERENCEVALUE']._serialized_end=442
  _globals['_SECRET']._serialized_start=444
  _globals['_SECRET']._serialized_end=500
  _globals['_KUBERNETESSECRET']._serialized_start=502
  _globals['_KUBERNETESSECRET']._serialized_end=572
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/fly/fly_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import kubernetes_config_pb2 as prodvana_dot_common__config_dot_kubernetes__config__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dprodvana/fly/fly_config.proto\x12\x0cprodvana.fly\x1a.prodvana/common_config/kubernetes_config.proto\x1a\x17validate/validate.proto\"\xbc\x01\n\tFlyConfig\x12\x1a\n\x07inlined\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12>\n\x05local\x18\x02 \x01(\x0b\x32#.prodvana.common_config.LocalConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12@\n\x06remote\x18\x03 \x01(\x0b\x32$.prodvana.common_config.RemoteConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x42\x11\n\ntoml_oneof\x12\x03\xf8\x42\x01\x42HZFgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/flyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.fly.fly_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZFgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/fly'
  _FLYCONFIG.oneofs_by_name['toml_oneof']._options = None
  _FLYCONFIG.oneofs_by_name['toml_oneof']._serialized_options = b'\370B\001'
  _FLYCONFIG.fields_by_name['inlined']._options = None
  _FLYCONFIG.fields_by_name['inlined']._serialized_options = b'\372B\004r\002\020\001'
  _FLYCONFIG.fields_by_name['local']._options = None
  _FLYCONFIG.fields_by_name['local']._serialized_options = b'\372B\005\212\001\002\020\001'
  _FLYCONFIG.fields_by_name['remote']._options = None
  _FLYCONFIG.fields_by_name['remote']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_FLYCONFIG']._serialized_start=121
  _globals['_FLYCONFIG']._serialized_end=309
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/object/meta.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aprodvana/object/meta.proto\x12\x0fprodvana.object\x1a&prodvana/version/source_metadata.proto\"\xdf\x01\n\nObjectMeta\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x16\n\x0e\x63onfig_version\x18\x04 \x01(\t\x12(\n\x06source\x18\x05 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x06 \x01(\x0b\x32 .prodvana.version.SourceMetadata\x12)\n\x04type\x18\x07 \x01(\x0e\x32\x1b.prodvana.object.ObjectType*\x86\x01\n\nObjectType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07RUNTIME\x10\x01\x12\x0f\n\x0b\x41PPLICATION\x10\x02\x12\x0b\n\x07SERVICE\x10\x03\x12\x13\n\x0fRELEASE_CHANNEL\x10\x04\x12\x0e\n\nPROTECTION\x10\x05\x12\x0e\n\nDEPLOYMENT\x10\x06\x12\x0b\n\x07RELEASE\x10\x07\x42KZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/objectb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.object.meta_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/object'
  _globals['_OBJECTTYPE']._serialized_start=314
  _globals['_OBJECTTYPE']._serialized_end=448
  _globals['_OBJECTMETA']._serialized_start=88
  _globals['_OBJECTMETA']._serialized_end=311
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.workflow import workflow_manager_pb2 as prodvana_dot_workflow_dot_workflow__manager__pb2


class WorkflowManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListIntegrations = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/ListIntegrations',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListIntegrationsReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListIntegrationsResp.FromString,
                )
        self.DeleteIntegration = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/DeleteIntegration',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteIntegrationReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteIntegrationResp.FromString,
                )
        self.CreateContainerRegistryIntegration = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/CreateContainerRegistryIntegration',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateContainerRegistryIntegrationReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateContainerRegistryIntegrationRes.FromString,
                )
        self.DeleteContainerRegistryIntegration = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/DeleteContainerRegistryIntegration',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteContainerRegistryIntegrationReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteContainerRegistryIntegrationResp.FromString,
                )
        self.ListContainerRegistryIntegrations = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/ListContainerRegistryIntegrations',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListContainerRegistryIntegrationsReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListContainerRegistryIntegrationsResp.FromString,
                )
        self.GetContainerRegistryIntegration = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetContainerRegistryIntegration',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryIntegrationReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryIntegrationResp.FromString,
                )
        self.GetServiceImageInfo = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetServiceImageInfo',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetServiceImageInfoReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetServiceImageInfoResp.FromString,
                )
        self.GetContainerRegistryImages = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetContainerRegistryImages',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryImagesReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryImagesRes.FromString,
                )
        self.ListTrackedImageRepositories = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/ListTrackedImageRepositories',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListTrackedImageRepositoriesReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListTrackedImageRepositoriesResp.FromString,
                )
        self.GetTrackedImageRepository = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetTrackedImageRepository',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetTrackedImageRepositoryReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetTrackedImageRepositoryResp.FromString,
                )
        self.TrackImageRepositories = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/TrackImageRepositories',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.TrackImageRepositoriesReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.TrackImageRepositoriesResp.FromString,
                )
        self.StopTrackingImageRepository = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/StopTrackingImageRepository',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.StopTrackingImageRepositoryReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.StopTrackingImageRepositoryResp.FromString,
                )
        self.GetProgramDefaults = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetProgramDefaults',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetProgramDefaultsReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetProgramDefaultsResp.FromString,
                )
        self.GetImageCommitInfo = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetImageCommitInfo',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetImageCommitInfoReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetImageCommitInfoResp.FromString,
                )
        self.InstallSlack = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/InstallSlack',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallSlackReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallSlackResp.FromString,
                )
        self.UninstallSlack = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/UninstallSlack',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallSlackReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallSlackResp.FromString,
                )
        self.GetInstallSlackUrl = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetInstallSlackUrl',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallSlackUrlReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallSlackUrlResp.FromString,
                )
        self.InstallPagerDuty = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/InstallPagerDuty',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallPagerDutyReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallPagerDutyResp.FromString,
                )
        self.GetInstallPagerDutyUrl = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetInstallPagerDutyUrl',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallPagerDutyUrlReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallPagerDutyUrlResp.FromString,
                )
        self.UninstallPagerDuty = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/UninstallPagerDuty',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallPagerDutyReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallPagerDutyResp.FromString,
                )
        self.GetGrafanaInstallation = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetGrafanaInstallation',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetGrafanaInstallationReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetGrafanaInstallationResp.FromString,
                )
        self.InstallGrafana = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/InstallGrafana',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGrafanaReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGrafanaResp.FromString,
                )
        self.UninstallGrafana = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/UninstallGrafana',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallGrafanaReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallGrafanaResp.FromString,
                )
        self.ListHoneycombEnvironments = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/ListHoneycombEnvironments',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListHoneycombEnvironmentsReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListHoneycombEnvironmentsResp.FromString,
                )
        self.AddHoneycombEnvironment = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/AddHoneycombEnvironment',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.AddHoneycombEnvironmentReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.AddHoneycombEnvironmentResp.FromString,
                )
        self.UpdateHoneycombEnvironment = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/UpdateHoneycombEnvironment',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UpdateHoneycombEnvironmentReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UpdateHoneycombEnvironmentResp.FromString,
                )
        self.DeleteHoneycombEnvironment = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/DeleteHoneycombEnvironment',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteHoneycombEnvironmentReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteHoneycombEnvironmentResp.FromString,
                )
        self.UninstallHoneycomb = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/UninstallHoneycomb',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallHoneycombReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallHoneycombResp.FromString,
                )
        self.GetInstallGitHubUrl = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetInstallGitHubUrl',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallGitHubUrlReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallGitHubUrlResp.FromString,
                )
        self.CreateGitHubApp = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/CreateGitHubApp',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateGitHubAppReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateGitHubAppResp.FromString,
                )
        self.InstallGitHub = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/InstallGitHub',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGitHubReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGitHubResp.FromString,
                )
        self.ListRepoCommits = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/ListRepoCommits',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListRepoCommitsReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListRepoCommitsResp.FromString,
                )
        self.GetCommitInfo = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetCommitInfo',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetCommitInfoReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetCommitInfoResp.FromString,
                )
        self.InstallLast9 = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/InstallLast9',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallLast9Req.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallLast9Resp.FromString,
                )
        self.UninstallLast9 = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/UninstallLast9',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallLast9Req.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallLast9Resp.FromString,
                )
        self.GetLast9Installation = channel.unary_unary(
                '/prodvana.workflow.WorkflowManager/GetLast9Installation',
                request_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetLast9InstallationReq.SerializeToString,
                response_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetLast9InstallationResp.FromString,
                )


class WorkflowManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListIntegrations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateContainerRegistryIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteContainerRegistryIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListContainerRegistryIntegrations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContainerRegistryIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceImageInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContainerRegistryImages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTrackedImageRepositories(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTrackedImageRepository(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TrackImageRepositories(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopTrackingImageRepository(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProgramDefaults(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetImageCommitInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstallSlack(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UninstallSlack(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstallSlackUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstallPagerDuty(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstallPagerDutyUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UninstallPagerDuty(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGrafanaInstallation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstallGrafana(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UninstallGrafana(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListHoneycombEnvironments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddHoneycombEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateHoneycombEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteHoneycombEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UninstallHoneycomb(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInstallGitHubUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateGitHubApp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstallGitHub(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRepoCommits(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCommitInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InstallLast9(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UninstallLast9(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLast9Installation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkflowManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListIntegrations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIntegrations,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListIntegrationsReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListIntegrationsResp.SerializeToString,
            ),
            'DeleteIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteIntegration,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteIntegrationReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteIntegrationResp.SerializeToString,
            ),
            'CreateContainerRegistryIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateContainerRegistryIntegration,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateContainerRegistryIntegrationReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateContainerRegistryIntegrationRes.SerializeToString,
            ),
            'DeleteContainerRegistryIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteContainerRegistryIntegration,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteContainerRegistryIntegrationReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteContainerRegistryIntegrationResp.SerializeToString,
            ),
            'ListContainerRegistryIntegrations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListContainerRegistryIntegrations,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListContainerRegistryIntegrationsReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListContainerRegistryIntegrationsResp.SerializeToString,
            ),
            'GetContainerRegistryIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContainerRegistryIntegration,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryIntegrationReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryIntegrationResp.SerializeToString,
            ),
            'GetServiceImageInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceImageInfo,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetServiceImageInfoReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetServiceImageInfoResp.SerializeToString,
            ),
            'GetContainerRegistryImages': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContainerRegistryImages,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryImagesReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryImagesRes.SerializeToString,
            ),
            'ListTrackedImageRepositories': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTrackedImageRepositories,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListTrackedImageRepositoriesReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListTrackedImageRepositoriesResp.SerializeToString,
            ),
            'GetTrackedImageRepository': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTrackedImageRepository,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetTrackedImageRepositoryReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetTrackedImageRepositoryResp.SerializeToString,
            ),
            'TrackImageRepositories': grpc.unary_unary_rpc_method_handler(
                    servicer.TrackImageRepositories,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.TrackImageRepositoriesReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.TrackImageRepositoriesResp.SerializeToString,
            ),
            'StopTrackingImageRepository': grpc.unary_unary_rpc_method_handler(
                    servicer.StopTrackingImageRepository,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.StopTrackingImageRepositoryReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.StopTrackingImageRepositoryResp.SerializeToString,
            ),
            'GetProgramDefaults': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProgramDefaults,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetProgramDefaultsReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetProgramDefaultsResp.SerializeToString,
            ),
            'GetImageCommitInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetImageCommitInfo,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetImageCommitInfoReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetImageCommitInfoResp.SerializeToString,
            ),
            'InstallSlack': grpc.unary_unary_rpc_method_handler(
                    servicer.InstallSlack,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallSlackReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallSlackResp.SerializeToString,
            ),
            'UninstallSlack': grpc.unary_unary_rpc_method_handler(
                    servicer.UninstallSlack,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallSlackReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallSlackResp.SerializeToString,
            ),
            'GetInstallSlackUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstallSlackUrl,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallSlackUrlReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallSlackUrlResp.SerializeToString,
            ),
            'InstallPagerDuty': grpc.unary_unary_rpc_method_handler(
                    servicer.InstallPagerDuty,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallPagerDutyReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallPagerDutyResp.SerializeToString,
            ),
            'GetInstallPagerDutyUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstallPagerDutyUrl,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallPagerDutyUrlReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallPagerDutyUrlResp.SerializeToString,
            ),
            'UninstallPagerDuty': grpc.unary_unary_rpc_method_handler(
                    servicer.UninstallPagerDuty,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallPagerDutyReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallPagerDutyResp.SerializeToString,
            ),
            'GetGrafanaInstallation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGrafanaInstallation,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetGrafanaInstallationReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetGrafanaInstallationResp.SerializeToString,
            ),
            'InstallGrafana': grpc.unary_unary_rpc_method_handler(
                    servicer.InstallGrafana,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGrafanaReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGrafanaResp.SerializeToString,
            ),
            'UninstallGrafana': grpc.unary_unary_rpc_method_handler(
                    servicer.UninstallGrafana,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallGrafanaReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallGrafanaResp.SerializeToString,
            ),
            'ListHoneycombEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListHoneycombEnvironments,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListHoneycombEnvironmentsReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListHoneycombEnvironmentsResp.SerializeToString,
            ),
            'AddHoneycombEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.AddHoneycombEnvironment,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.AddHoneycombEnvironmentReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.AddHoneycombEnvironmentResp.SerializeToString,
            ),
            'UpdateHoneycombEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateHoneycombEnvironment,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UpdateHoneycombEnvironmentReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UpdateHoneycombEnvironmentResp.SerializeToString,
            ),
            'DeleteHoneycombEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteHoneycombEnvironment,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteHoneycombEnvironmentReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteHoneycombEnvironmentResp.SerializeToString,
            ),
            'UninstallHoneycomb': grpc.unary_unary_rpc_method_handler(
                    servicer.UninstallHoneycomb,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallHoneycombReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallHoneycombResp.SerializeToString,
            ),
            'GetInstallGitHubUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstallGitHubUrl,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallGitHubUrlReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallGitHubUrlResp.SerializeToString,
            ),
            'CreateGitHubApp': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateGitHubApp,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateGitHubAppReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.CreateGitHubAppResp.SerializeToString,
            ),
            'InstallGitHub': grpc.unary_unary_rpc_method_handler(
                    servicer.InstallGitHub,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGitHubReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGitHubResp.SerializeToString,
            ),
            'ListRepoCommits': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRepoCommits,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListRepoCommitsReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.ListRepoCommitsResp.SerializeToString,
            ),
            'GetCommitInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCommitInfo,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetCommitInfoReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetCommitInfoResp.SerializeToString,
            ),
            'InstallLast9': grpc.unary_unary_rpc_method_handler(
                    servicer.InstallLast9,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallLast9Req.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.InstallLast9Resp.SerializeToString,
            ),
            'UninstallLast9': grpc.unary_unary_rpc_method_handler(
                    servicer.UninstallLast9,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallLast9Req.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallLast9Resp.SerializeToString,
            ),
            'GetLast9Installation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLast9Installation,
                    request_deserializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetLast9InstallationReq.FromString,
                    response_serializer=prodvana_dot_workflow_dot_workflow__manager__pb2.GetLast9InstallationResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.workflow.WorkflowManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WorkflowManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListIntegrations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/ListIntegrations',
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListIntegrationsReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListIntegrationsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/DeleteIntegration',
            prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteIntegrationReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteIntegrationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateContainerRegistryIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/CreateContainerRegistryIntegration',
            prodvana_dot_workflow_dot_workflow__manager__pb2.CreateContainerRegistryIntegrationReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.CreateContainerRegistryIntegrationRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteContainerRegistryIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/DeleteContainerRegistryIntegration',
            prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteContainerRegistryIntegrationReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteContainerRegistryIntegrationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListContainerRegistryIntegrations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/ListContainerRegistryIntegrations',
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListContainerRegistryIntegrationsReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListContainerRegistryIntegrationsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetContainerRegistryIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetContainerRegistryIntegration',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryIntegrationReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryIntegrationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceImageInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetServiceImageInfo',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetServiceImageInfoReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetServiceImageInfoResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetContainerRegistryImages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetContainerRegistryImages',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryImagesReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetContainerRegistryImagesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTrackedImageRepositories(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/ListTrackedImageRepositories',
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListTrackedImageRepositoriesReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListTrackedImageRepositoriesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTrackedImageRepository(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetTrackedImageRepository',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetTrackedImageRepositoryReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetTrackedImageRepositoryResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TrackImageRepositories(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/TrackImageRepositories',
            prodvana_dot_workflow_dot_workflow__manager__pb2.TrackImageRepositoriesReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.TrackImageRepositoriesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopTrackingImageRepository(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/StopTrackingImageRepository',
            prodvana_dot_workflow_dot_workflow__manager__pb2.StopTrackingImageRepositoryReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.StopTrackingImageRepositoryResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProgramDefaults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetProgramDefaults',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetProgramDefaultsReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetProgramDefaultsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetImageCommitInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetImageCommitInfo',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetImageCommitInfoReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetImageCommitInfoResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InstallSlack(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/InstallSlack',
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallSlackReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallSlackResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UninstallSlack(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/UninstallSlack',
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallSlackReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallSlackResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstallSlackUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetInstallSlackUrl',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallSlackUrlReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallSlackUrlResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InstallPagerDuty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/InstallPagerDuty',
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallPagerDutyReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallPagerDutyResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstallPagerDutyUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetInstallPagerDutyUrl',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallPagerDutyUrlReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallPagerDutyUrlResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UninstallPagerDuty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/UninstallPagerDuty',
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallPagerDutyReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallPagerDutyResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGrafanaInstallation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetGrafanaInstallation',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetGrafanaInstallationReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetGrafanaInstallationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InstallGrafana(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/InstallGrafana',
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGrafanaReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGrafanaResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UninstallGrafana(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/UninstallGrafana',
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallGrafanaReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallGrafanaResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListHoneycombEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/ListHoneycombEnvironments',
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListHoneycombEnvironmentsReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListHoneycombEnvironmentsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddHoneycombEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/AddHoneycombEnvironment',
            prodvana_dot_workflow_dot_workflow__manager__pb2.AddHoneycombEnvironmentReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.AddHoneycombEnvironmentResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateHoneycombEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/UpdateHoneycombEnvironment',
            prodvana_dot_workflow_dot_workflow__manager__pb2.UpdateHoneycombEnvironmentReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.UpdateHoneycombEnvironmentResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteHoneycombEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/DeleteHoneycombEnvironment',
            prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteHoneycombEnvironmentReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.DeleteHoneycombEnvironmentResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UninstallHoneycomb(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/UninstallHoneycomb',
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallHoneycombReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallHoneycombResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetInstallGitHubUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetInstallGitHubUrl',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallGitHubUrlReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetInstallGitHubUrlResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateGitHubApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/CreateGitHubApp',
            prodvana_dot_workflow_dot_workflow__manager__pb2.CreateGitHubAppReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.CreateGitHubAppResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InstallGitHub(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/InstallGitHub',
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGitHubReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallGitHubResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListRepoCommits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/ListRepoCommits',
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListRepoCommitsReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.ListRepoCommitsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCommitInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetCommitInfo',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetCommitInfoReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetCommitInfoResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InstallLast9(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/InstallLast9',
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallLast9Req.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.InstallLast9Resp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UninstallLast9(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/UninstallLast9',
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallLast9Req.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.UninstallLast9Resp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLast9Installation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.workflow.WorkflowManager/GetLast9Installation',
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetLast9InstallationReq.SerializeToString,
            prodvana_dot_workflow_dot_workflow__manager__pb2.GetLast9InstallationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/capability/capability.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.prodvana.pipelines import pipelines_pb2 as prodvana_dot_pipelines_dot_pipelines__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$prodvana/capability/capability.proto\x12\x13prodvana.capability\x1a prodvana/common_config/env.proto\x1a\"prodvana/pipelines/pipelines.proto\x1a\x17validate/validate.proto\"\xdb\x01\n!PerReleaseChannelCapabilityConfig\x12 \n\x0frelease_channel\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12@\n\x07inlined\x18\x02 \x01(\x0b\x32-.prodvana.capability.CapabilityInstanceConfigH\x00\x12\x39\n\x03ref\x18\x03 \x01(\x0b\x32*.prodvana.capability.CapabilityInstanceRefH\x00\x42\x17\n\x10\x64\x65\x66inition_oneof\x12\x03\xf8\x42\x01\"\x8d\x01\n\x10\x43\x61pabilityConfig\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x62\n\x13per_release_channel\x18\x02 \x03(\x0b\x32\x36.prodvana.capability.PerReleaseChannelCapabilityConfigB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\"\xa5\x02\n\x18\x43\x61pabilityInstanceConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12l\n\x03\x65nv\x18\x02 \x03(\x0b\x32\x36.prodvana.capability.CapabilityInstanceConfig.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x12?\n\x0epre_push_tasks\x18\x03 \x03(\x0b\x32\x18.prodvana.pipelines.TaskB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\".\n\x15\x43\x61pabilityInstanceRef\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42OZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/capabilityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.capability.capability_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/capability'
  _PERRELEASECHANNELCAPABILITYCONFIG.oneofs_by_name['definition_oneof']._options = None
  _PERRELEASECHANNELCAPABILITYCONFIG.oneofs_by_name['definition_oneof']._serialized_options = b'\370B\001'
  _PERRELEASECHANNELCAPABILITYCONFIG.fields_by_name['release_channel']._options = None
  _PERRELEASECHANNELCAPABILITYCONFIG.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _CAPABILITYCONFIG.fields_by_name['name']._options = None
  _CAPABILITYCONFIG.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CAPABILITYCONFIG.fields_by_name['per_release_channel']._options = None
  _CAPABILITYCONFIG.fields_by_name['per_release_channel']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _CAPABILITYINSTANCECONFIG_ENVENTRY._options = None
  _CAPABILITYINSTANCECONFIG_ENVENTRY._serialized_options = b'8\001'
  _CAPABILITYINSTANCECONFIG.fields_by_name['env']._options = None
  _CAPABILITYINSTANCECONFIG.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _CAPABILITYINSTANCECONFIG.fields_by_name['pre_push_tasks']._options = None
  _CAPABILITYINSTANCECONFIG.fields_by_name['pre_push_tasks']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _CAPABILITYINSTANCEREF.fields_by_name['name']._options = None
  _CAPABILITYINSTANCEREF.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_PERRELEASECHANNELCAPABILITYCONFIG']._serialized_start=157
  _globals['_PERRELEASECHANNELCAPABILITYCONFIG']._serialized_end=376
  _globals['_CAPABILITYCONFIG']._serialized_start=379
  _globals['_CAPABILITYCONFIG']._serialized_end=520
  _globals['_CAPABILITYINSTANCECONFIG']._serialized_start=523
  _globals['_CAPABILITYINSTANCECONFIG']._serialized_end=816
  _globals['_CAPABILITYINSTANCECONFIG_ENVENTRY']._serialized_start=740
  _globals['_CAPABILITYINSTANCECONFIG_ENVENTRY']._serialized_end=816
  _globals['_CAPABILITYINSTANCEREF']._serialized_start=818
  _globals['_CAPABILITYINSTANCEREF']._serialized_end=864
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AuthToken(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    token: builtins.str
    def __init__(
        self,
        *,
        token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token", b"token"]) -> None: ...

global___AuthToken = AuthToken

class ApiTokenInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRES_TIMESTAMP_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    name: builtins.str
    description: builtins.str
    @property
    def expires_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        expires_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "expires_timestamp", b"expires_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "expires_timestamp", b"expires_timestamp", "name", b"name"]) -> None: ...

global___ApiTokenInfo = ApiTokenInfo

class AuthContext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTH_TOKEN_FIELD_NUMBER: builtins.int
    API_TOKEN_FIELD_NUMBER: builtins.int
    ADDR_FIELD_NUMBER: builtins.int
    @property
    def auth_token(self) -> global___AuthToken: ...
    api_token: builtins.str
    addr: builtins.str
    def __init__(
        self,
        *,
        auth_token: global___AuthToken | None = ...,
        api_token: builtins.str = ...,
        addr: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_token", b"auth_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["addr", b"addr", "api_token", b"api_token", "auth_token", b"auth_token"]) -> None: ...

global___AuthContext = AuthContext

class Session(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ContextsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___AuthContext: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___AuthContext | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class AdminContextsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___AuthContext: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___AuthContext | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONTEXTS_FIELD_NUMBER: builtins.int
    CURRENT_CONTEXT_FIELD_NUMBER: builtins.int
    ADMIN_CONTEXTS_FIELD_NUMBER: builtins.int
    CURRENT_ADMIN_CONTEXT_FIELD_NUMBER: builtins.int
    @property
    def contexts(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___AuthContext]: ...
    current_context: builtins.str
    @property
    def admin_contexts(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___AuthContext]: ...
    current_admin_context: builtins.str
    def __init__(
        self,
        *,
        contexts: collections.abc.Mapping[builtins.str, global___AuthContext] | None = ...,
        current_context: builtins.str = ...,
        admin_contexts: collections.abc.Mapping[builtins.str, global___AuthContext] | None = ...,
        current_admin_context: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_contexts", b"admin_contexts", "contexts", b"contexts", "current_admin_context", b"current_admin_context", "current_context", b"current_context"]) -> None: ...

global___Session = Session



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.pvn_wrapper.job_manager_pb2

class JobManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ReportJobResult: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.pvn_wrapper.job_manager_pb2.ReportJobResultReq,
        prodvana.proto.prodvana.pvn_wrapper.job_manager_pb2.ReportJobResultResp,
    ]

class JobManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ReportJobResult(
        self,
        request: prodvana.proto.prodvana.pvn_wrapper.job_manager_pb2.ReportJobResultReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.pvn_wrapper.job_manager_pb2.ReportJobResultResp: ...

def add_JobManagerServicer_to_server(servicer: JobManagerServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/runtimes/runtimes_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'prodvana/runtimes/runtimes_config.proto\x12\x11prodvana.runtimes\x1a\x17validate/validate.proto\"\xc8\x02\n\x1eK8SRuntimeInitializationConfig\x12\x13\n\x0b\x61gent_image\x18\x01 \x01(\t\x12\x12\n\nauth_token\x18\x03 \x01(\t\x12\x1c\n\x14use_resource_default\x18\x04 \x01(\x08\x12\"\n\x1ainteraction_server_address\x18\x05 \x01(\t\x12P\n\x08\x65nv_vars\x18\x06 \x03(\x0b\x32>.prodvana.runtimes.K8SRuntimeInitializationConfig.EnvVarsEntry\x12 \n\x18\x61gent_externally_managed\x18\x07 \x01(\x08\x1a.\n\x0c\x45nvVarsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x02\x10\x03R\x11\x61piserver_address\"s\n\x1bRuntimeInitializationConfig\x12@\n\x03k8s\x18\x01 \x01(\x0b\x32\x31.prodvana.runtimes.K8SRuntimeInitializationConfigH\x00\x42\x12\n\x10runtime_specific\"\x91\x02\n\x1d\x43ontainerOrchestrationRuntime\x12\x43\n\x03k8s\x18\x01 \x01(\x0b\x32\x34.prodvana.runtimes.ContainerOrchestrationRuntime.K8sH\x00\x12\x43\n\x03\x65\x63s\x18\x02 \x01(\x0b\x32\x34.prodvana.runtimes.ContainerOrchestrationRuntime.ECSH\x00\x1a\x36\n\x03K8s\x12\x1a\n\tnamespace\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x0bpvn_managed\x18\x02 \x01(\x08\x1a\x1e\n\x03\x45\x43S\x12\x17\n\x06prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\x0e\n\x07\x62\x61\x63kend\x12\x03\xf8\x42\x01\"\xb9\x01\n\x16RuntimeExecutionConfig\x12<\n\x07runtime\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12S\n\x17\x63ontainer_orchestration\x18\x02 \x01(\x0b\x32\x30.prodvana.runtimes.ContainerOrchestrationRuntimeH\x00\x42\x0c\n\ntype_oneofBMZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/runtimesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.runtimes.runtimes_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/runtimes'
  _K8SRUNTIMEINITIALIZATIONCONFIG_ENVVARSENTRY._options = None
  _K8SRUNTIMEINITIALIZATIONCONFIG_ENVVARSENTRY._serialized_options = b'8\001'
  _CONTAINERORCHESTRATIONRUNTIME_K8S.fields_by_name['namespace']._options = None
  _CONTAINERORCHESTRATIONRUNTIME_K8S.fields_by_name['namespace']._serialized_options = b'\372B\004r\002\020\001'
  _CONTAINERORCHESTRATIONRUNTIME_ECS.fields_by_name['prefix']._options = None
  _CONTAINERORCHESTRATIONRUNTIME_ECS.fields_by_name['prefix']._serialized_options = b'\372B\004r\002\020\001'
  _CONTAINERORCHESTRATIONRUNTIME.oneofs_by_name['backend']._options = None
  _CONTAINERORCHESTRATIONRUNTIME.oneofs_by_name['backend']._serialized_options = b'\370B\001'
  _RUNTIMEEXECUTIONCONFIG.fields_by_name['runtime']._options = None
  _RUNTIMEEXECUTIONCONFIG.fields_by_name['runtime']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _globals['_K8SRUNTIMEINITIALIZATIONCONFIG']._serialized_start=88
  _globals['_K8SRUNTIMEINITIALIZATIONCONFIG']._serialized_end=416
  _globals['_K8SRUNTIMEINITIALIZATIONCONFIG_ENVVARSENTRY']._serialized_start=345
  _globals['_K8SRUNTIMEINITIALIZATIONCONFIG_ENVVARSENTRY']._serialized_end=391
  _globals['_RUNTIMEINITIALIZATIONCONFIG']._serialized_start=418
  _globals['_RUNTIMEINITIALIZATIONCONFIG']._serialized_end=533
  _globals['_CONTAINERORCHESTRATIONRUNTIME']._serialized_start=536
  _globals['_CONTAINERORCHESTRATIONRUNTIME']._serialized_end=809
  _globals['_CONTAINERORCHESTRATIONRUNTIME_K8S']._serialized_start=707
  _globals['_CONTAINERORCHESTRATIONRUNTIME_K8S']._serialized_end=761
  _globals['_CONTAINERORCHESTRATIONRUNTIME_ECS']._serialized_start=763
  _globals['_CONTAINERORCHESTRATIONRUNTIME_ECS']._serialized_end=793
  _globals['_RUNTIMEEXECUTIONCONFIG']._serialized_start=812
  _globals['_RUNTIMEEXECUTIONCONFIG']._serialized_end=997
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/managed_resource/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'prodvana/managed_resource/manager.proto\x12\x19prodvana.managed_resource\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd4\x03\n\x16\x43onfigureK8sClusterReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12S\n\x0bgcp_options\x18\x02 \x01(\x0b\x32<.prodvana.managed_resource.ConfigureK8sClusterReq.GcpOptionsH\x00\x12S\n\x0b\x65ks_options\x18\x07 \x01(\x0b\x32<.prodvana.managed_resource.ConfigureK8sClusterReq.EKSOptionsH\x00\x12\x15\n\rinstance_type\x18\x03 \x01(\t\x12\x16\n\x0enodepool_zones\x18\x04 \x03(\t\x12\x1b\n\x13node_count_per_zone\x18\x05 \x01(\x05\x12\x0e\n\x06region\x18\x06 \x01(\t\x1a\x32\n\nGcpOptions\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x13\n\x0b\x63redentials\x18\x02 \x01(\t\x1aZ\n\nEKSOptions\x12\x12\n\naccess_key\x18\x01 \x01(\t\x12\x12\n\nsecret_key\x18\x02 \x01(\t\x12\x12\n\naccount_id\x18\x03 \x01(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\tB\x16\n\x14\x63loud_provider_oneof\"w\n\x17\x43onfigureK8sClusterResp\x12\n\n\x02id\x18\x04 \x01(\t\x12*\n\x06run_id\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0b\x61rchive_url\x18\x03 \x01(\t\"\xbb\x02\n\x0fManagedResource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x42\n\nlatest_run\x18\x04 \x01(\x0b\x32..prodvana.managed_resource.ManagedResource.Run\x1a\xbb\x01\n\x03Run\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\x12\x10\n\x08terminal\x18\x03 \x01(\x08\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x06 \x01(\t\"1\n\x15GetManagedResourceReq\x12\x18\n\x10managed_resource\x18\x01 \x01(\t\"^\n\x16GetManagedResourceResp\x12\x44\n\x10managed_resource\x18\x01 \x01(\x0b\x32*.prodvana.managed_resource.ManagedResource\"\x19\n\x17ListManagedResourcesReq\"a\n\x18ListManagedResourcesResp\x12\x45\n\x11managed_resources\x18\x01 \x03(\x0b\x32*.prodvana.managed_resource.ManagedResource\":\n\rGetArchiveReq\x12\x18\n\x10managed_resource\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x1f\n\x0eGetArchiveResp\x12\r\n\x05\x62ytes\x18\x01 \x01(\x0c\"v\n\x0eMarkRunDoneReq\x12\x18\n\x10managed_resource\x18\x01 \x01(\t\x12*\n\x06run_id\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tsucceeded\x18\x03 \x01(\x08\x12\x0b\n\x03msg\x18\x04 \x01(\t\"\x11\n\x0fMarkRunDoneResp\"4\n\x18\x44\x65leteManagedResourceReq\x12\x18\n\x10managed_resource\x18\x01 \x01(\t\"S\n\x19\x44\x65leteManagedResourceResp\x12\n\n\x02id\x18\x01 \x01(\t\x12*\n\x06run_id\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xf3\x07\n\x0fResourceManager\x12\xac\x01\n\x13\x43onfigureK8sCluster\x12\x31.prodvana.managed_resource.ConfigureK8sClusterReq\x1a\x32.prodvana.managed_resource.ConfigureK8sClusterResp\".\x82\xd3\xe4\x93\x02(\"#/v1/managed_resources/k8s/configure:\x01*\x12\xad\x01\n\x12GetManagedResource\x12\x30.prodvana.managed_resource.GetManagedResourceReq\x1a\x31.prodvana.managed_resource.GetManagedResourceResp\"2\x82\xd3\xe4\x93\x02,\x12*/v1/managed_resources/{managed_resource=*}\x12\x9e\x01\n\x14ListManagedResources\x12\x32.prodvana.managed_resource.ListManagedResourcesReq\x1a\x33.prodvana.managed_resource.ListManagedResourcesResp\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/managed_resources\x12\xb7\x01\n\nGetArchive\x12(.prodvana.managed_resource.GetArchiveReq\x1a).prodvana.managed_resource.GetArchiveResp\"R\x82\xd3\xe4\x93\x02L\x12J/v1/managed_resources/{managed_resource=*}/archive/archive/archive/archive0\x01\x12\xbd\x01\n\x15\x44\x65leteManagedResource\x12\x33.prodvana.managed_resource.DeleteManagedResourceReq\x1a\x34.prodvana.managed_resource.DeleteManagedResourceResp\"9\x82\xd3\xe4\x93\x02\x33*1/v1/managed_resources/{managed_resource=*}/delete\x12\x66\n\x0bMarkRunDone\x12).prodvana.managed_resource.MarkRunDoneReq\x1a*.prodvana.managed_resource.MarkRunDoneResp\"\x00\x42UZSgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/managed_resourceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.managed_resource.manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZSgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/managed_resource'
  _RESOURCEMANAGER.methods_by_name['ConfigureK8sCluster']._options = None
  _RESOURCEMANAGER.methods_by_name['ConfigureK8sCluster']._serialized_options = b'\202\323\344\223\002(\"#/v1/managed_resources/k8s/configure:\001*'
  _RESOURCEMANAGER.methods_by_name['GetManagedResource']._options = None
  _RESOURCEMANAGER.methods_by_name['GetManagedResource']._serialized_options = b'\202\323\344\223\002,\022*/v1/managed_resources/{managed_resource=*}'
  _RESOURCEMANAGER.methods_by_name['ListManagedResources']._options = None
  _RESOURCEMANAGER.methods_by_name['ListManagedResources']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/managed_resources'
  _RESOURCEMANAGER.methods_by_name['GetArchive']._options = None
  _RESOURCEMANAGER.methods_by_name['GetArchive']._serialized_options = b'\202\323\344\223\002L\022J/v1/managed_resources/{managed_resource=*}/archive/archive/archive/archive'
  _RESOURCEMANAGER.methods_by_name['DeleteManagedResource']._options = None
  _RESOURCEMANAGER.methods_by_name['DeleteManagedResource']._serialized_options = b'\202\323\344\223\0023*1/v1/managed_resources/{managed_resource=*}/delete'
  _globals['_CONFIGUREK8SCLUSTERREQ']._serialized_start=134
  _globals['_CONFIGUREK8SCLUSTERREQ']._serialized_end=602
  _globals['_CONFIGUREK8SCLUSTERREQ_GCPOPTIONS']._serialized_start=436
  _globals['_CONFIGUREK8SCLUSTERREQ_GCPOPTIONS']._serialized_end=486
  _globals['_CONFIGUREK8SCLUSTERREQ_EKSOPTIONS']._serialized_start=488
  _globals['_CONFIGUREK8SCLUSTERREQ_EKSOPTIONS']._serialized_end=578
  _globals['_CONFIGUREK8SCLUSTERRESP']._serialized_start=604
  _globals['_CONFIGUREK8SCLUSTERRESP']._serialized_end=723
  _globals['_MANAGEDRESOURCE']._serialized_start=726
  _globals['_MANAGEDRESOURCE']._serialized_end=1041
  _globals['_MANAGEDRESOURCE_RUN']._serialized_start=854
  _globals['_MANAGEDRESOURCE_RUN']._serialized_end=1041
  _globals['_GETMANAGEDRESOURCEREQ']._serialized_start=1043
  _globals['_GETMANAGEDRESOURCEREQ']._serialized_end=1092
  _globals['_GETMANAGEDRESOURCERESP']._serialized_start=1094
  _globals['_GETMANAGEDRESOURCERESP']._serialized_end=1188
  _globals['_LISTMANAGEDRESOURCESREQ']._serialized_start=1190
  _globals['_LISTMANAGEDRESOURCESREQ']._serialized_end=1215
  _globals['_LISTMANAGEDRESOURCESRESP']._serialized_start=1217
  _globals['_LISTMANAGEDRESOURCESRESP']._serialized_end=1314
  _globals['_GETARCHIVEREQ']._serialized_start=1316
  _globals['_GETARCHIVEREQ']._serialized_end=1374
  _globals['_GETARCHIVERESP']._serialized_start=1376
  _globals['_GETARCHIVERESP']._serialized_end=1407
  _globals['_MARKRUNDONEREQ']._serialized_start=1409
  _globals['_MARKRUNDONEREQ']._serialized_end=1527
  _globals['_MARKRUNDONERESP']._serialized_start=1529
  _globals['_MARKRUNDONERESP']._serialized_end=1546
  _globals['_DELETEMANAGEDRESOURCEREQ']._serialized_start=1548
  _globals['_DELETEMANAGEDRESOURCEREQ']._serialized_end=1600
  _globals['_DELETEMANAGEDRESOURCERESP']._serialized_start=1602
  _globals['_DELETEMANAGEDRESOURCERESP']._serialized_end=1685
  _globals['_RESOURCEMANAGER']._serialized_start=1688
  _globals['_RESOURCEMANAGER']._serialized_end=2699
# @@protoc_insertion_point(module_scope)
